/**
 * Copyright (c) 2022 Facundo Carbonel / LogIt
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 */

'use strict';

var winston = require('winston');

function _interopDefaultLegacy (e) { return e && typeof e === 'object' && 'default' in e ? e : { 'default': e }; }

var winston__default = /*#__PURE__*/_interopDefaultLegacy(winston);

var levels = {
    error: 0,
    warn: 1,
    info: 2,
    http: 3,
    verbose: 4,
    debug: 5,
};
var level = function () {
    var env = process.env.NODE_ENV || 'development';
    var isDevelopment = env === 'development';
    return isDevelopment ? 'debug' : 'http';
};
var colors = {
    error: 'red',
    warn: 'yellow',
    info: 'magenta',
    http: 'blue',
    verbose: 'green',
    debug: 'white',
};
winston__default["default"].addColors(colors);
var format = winston__default["default"].format.combine(winston__default["default"].format.timestamp({ format: 'YYYYMMDD HH:mm:ss' }), winston__default["default"].format.printf(function (info) { return "".concat(info.timestamp, " ").concat(info.level, ": ").concat(info.message); }));
var transports = [
    new winston__default["default"].transports.Console({
        format: winston__default["default"].format.colorize({ all: true }),
    }),
    new winston__default["default"].transports.File({
        filename: 'logs/error.log',
        level: 'error',
    }),
    new winston__default["default"].transports.File({
        filename: 'logs/info.log',
        level: 'info',
    }),
    new winston__default["default"].transports.File({ filename: 'logs/all.log' }),
];
var logger = winston__default["default"].createLogger({
    level: level(),
    levels: levels,
    format: format,
    transports: transports,
    exitOnError: false,
});
var DotLogs = (function () {
    function DotLogs() {
        if (typeof DotLogs.instance == 'object') {
            return DotLogs.instance;
        }
        DotLogs.instance = this;
        return this;
    }
    DotLogs.prototype.error = function (message) {
        logger.error(message);
    };
    DotLogs.prototype.warn = function (message) {
        logger.warn(message);
    };
    DotLogs.prototype.info = function (message) {
        logger.info(message);
    };
    DotLogs.prototype.http = function (message) {
        logger.http(message);
    };
    DotLogs.prototype.debug = function (message) {
        logger.debug(message);
    };
    DotLogs.prototype.verbose = function (message) {
        logger.verbose(message);
    };
    return DotLogs;
}());

module.exports = DotLogs;
