/**
 * Copyright (c) 2022 Facundo Carbonel / LogIt
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 */

import winston from 'winston';

var levels = {
    error: 0,
    warn: 1,
    info: 2,
    http: 3,
    verbose: 4,
    debug: 5,
};
var level = function () {
    var env = process.env.NODE_ENV || 'development';
    var isDevelopment = env === 'development';
    return isDevelopment ? 'debug' : 'http';
};
var colors = {
    error: 'red',
    warn: 'yellow',
    info: 'magenta',
    http: 'blue',
    verbose: 'green',
    debug: 'white',
};
winston.addColors(colors);
var format = winston.format.combine(winston.format.timestamp({ format: 'YYYYMMDD HH:mm:ss' }), winston.format.printf(function (info) { return "".concat(info.timestamp, " ").concat(info.level, ": ").concat(info.message); }));
var transports = [
    new winston.transports.Console({
        format: winston.format.colorize({ all: true }),
    }),
    new winston.transports.File({
        filename: 'logs/error.log',
        level: 'error',
    }),
    new winston.transports.File({
        filename: 'logs/info.log',
        level: 'info',
    }),
    new winston.transports.File({ filename: 'logs/all.log' }),
];
var logger = winston.createLogger({
    level: level(),
    levels: levels,
    format: format,
    transports: transports,
    exitOnError: false,
});
var DotLogs = (function () {
    function DotLogs() {
        if (typeof DotLogs.instance == 'object') {
            return DotLogs.instance;
        }
        DotLogs.instance = this;
        return this;
    }
    DotLogs.prototype.error = function (message) {
        logger.error(message);
    };
    DotLogs.prototype.warn = function (message) {
        logger.warn(message);
    };
    DotLogs.prototype.info = function (message) {
        logger.info(message);
    };
    DotLogs.prototype.http = function (message) {
        logger.http(message);
    };
    DotLogs.prototype.debug = function (message) {
        logger.debug(message);
    };
    DotLogs.prototype.verbose = function (message) {
        logger.verbose(message);
    };
    return DotLogs;
}());

export { DotLogs as default };
